from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Acp:
	"""Acp commands group definition. 14 total commands, 2 Sub-groups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("acp", core, parent)

	@property
	def obw(self):
		"""obw commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_obw'):
			from .Acp_.Obw import Obw
			self._obw = Obw(self._core, self._base)
		return self._obw

	@property
	def limit(self):
		"""limit commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_limit'):
			from .Acp_.Limit import Limit
			self._limit = Limit(self._core, self._base)
		return self._limit

	def get_mo_exception(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:MOEXception \n
		Snippet: value: bool = driver.configure.gprfMeasurement.acp.get_mo_exception() \n
		Specifies whether measurement results that the R&S CMA180 identifies as faulty or inaccurate are rejected. \n
			:return: meas_on_exception: OFF | ON OFF Faulty results are rejected ON Results are never rejected
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:ACP:MOEXception?')
		return Conversions.str_to_bool(response)

	def set_mo_exception(self, meas_on_exception: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:MOEXception \n
		Snippet: driver.configure.gprfMeasurement.acp.set_mo_exception(meas_on_exception = False) \n
		Specifies whether measurement results that the R&S CMA180 identifies as faulty or inaccurate are rejected. \n
			:param meas_on_exception: OFF | ON OFF Faulty results are rejected ON Results are never rejected
		"""
		param = Conversions.bool_to_str(meas_on_exception)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:ACP:MOEXception {param}')

	def get_timeout(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:TOUT \n
		Snippet: value: float = driver.configure.gprfMeasurement.acp.get_timeout() \n
		Defines a timeout for the measurement. The timer is started when the measurement is initiated via a READ or INIT command.
		It is not started if the measurement is initiated via the graphical user interface. The timer is reset after the first
		measurement cycle. If the first measurement cycle has not been completed when the timer expires, the measurement is
		stopped and the reliability indicator is set to 1. Still running READ, FETCh or CALCulate commands are completed,
		returning the available results. At least for some results, there are no values at all or the statistical depth has not
		been reached. A timeout of 0 s corresponds to an infinite measurement timeout. \n
			:return: tcd_timeout: Unit: s
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:ACP:TOUT?')
		return Conversions.str_to_float(response)

	def set_timeout(self, tcd_timeout: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:TOUT \n
		Snippet: driver.configure.gprfMeasurement.acp.set_timeout(tcd_timeout = 1.0) \n
		Defines a timeout for the measurement. The timer is started when the measurement is initiated via a READ or INIT command.
		It is not started if the measurement is initiated via the graphical user interface. The timer is reset after the first
		measurement cycle. If the first measurement cycle has not been completed when the timer expires, the measurement is
		stopped and the reliability indicator is set to 1. Still running READ, FETCh or CALCulate commands are completed,
		returning the available results. At least for some results, there are no values at all or the statistical depth has not
		been reached. A timeout of 0 s corresponds to an infinite measurement timeout. \n
			:param tcd_timeout: Unit: s
		"""
		param = Conversions.decimal_value_to_str(tcd_timeout)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:ACP:TOUT {param}')

	# noinspection PyTypeChecker
	def get_repetition(self) -> enums.Repeat:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:REPetition \n
		Snippet: value: enums.Repeat = driver.configure.gprfMeasurement.acp.get_repetition() \n
		Selects whether the measurement is repeated continuously or not. \n
			:return: repetition: SINGleshot | CONTinuous SINGleshot Single-shot measurement, stopped after one measurement cycle CONTinuous Continuous measurement, running until explicitly terminated
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:ACP:REPetition?')
		return Conversions.str_to_scalar_enum(response, enums.Repeat)

	def set_repetition(self, repetition: enums.Repeat) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:REPetition \n
		Snippet: driver.configure.gprfMeasurement.acp.set_repetition(repetition = enums.Repeat.CONTinuous) \n
		Selects whether the measurement is repeated continuously or not. \n
			:param repetition: SINGleshot | CONTinuous SINGleshot Single-shot measurement, stopped after one measurement cycle CONTinuous Continuous measurement, running until explicitly terminated
		"""
		param = Conversions.enum_scalar_to_str(repetition, enums.Repeat)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:ACP:REPetition {param}')

	def get_rcoupling(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:RCOupling \n
		Snippet: value: bool = driver.configure.gprfMeasurement.acp.get_rcoupling() \n
		Couples the repetition mode (single shot or continuous) of all measurements. \n
			:return: repetition_coupl: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:ACP:RCOupling?')
		return Conversions.str_to_bool(response)

	def set_rcoupling(self, repetition_coupl: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:RCOupling \n
		Snippet: driver.configure.gprfMeasurement.acp.set_rcoupling(repetition_coupl = False) \n
		Couples the repetition mode (single shot or continuous) of all measurements. \n
			:param repetition_coupl: OFF | ON
		"""
		param = Conversions.bool_to_str(repetition_coupl)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:ACP:RCOupling {param}')

	def get_scount(self) -> int:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:SCOunt \n
		Snippet: value: int = driver.configure.gprfMeasurement.acp.get_scount() \n
		Specifies the number of measurement intervals per measurement cycle. One measurement interval delivers one set of
		'Current' results. \n
			:return: statistic_count: Range: 1 to 1000
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:ACP:SCOunt?')
		return Conversions.str_to_int(response)

	def set_scount(self, statistic_count: int) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:SCOunt \n
		Snippet: driver.configure.gprfMeasurement.acp.set_scount(statistic_count = 1) \n
		Specifies the number of measurement intervals per measurement cycle. One measurement interval delivers one set of
		'Current' results. \n
			:param statistic_count: Range: 1 to 1000
		"""
		param = Conversions.decimal_value_to_str(statistic_count)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:ACP:SCOunt {param}')

	def get_cspace(self) -> int:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:CSPace \n
		Snippet: value: int = driver.configure.gprfMeasurement.acp.get_cspace() \n
		Defines the channel spacing, that is the center frequency difference of two adjacent channels. \n
			:return: channel_space: Range: 100 Hz to 4 MHz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:ACP:CSPace?')
		return Conversions.str_to_int(response)

	def set_cspace(self, channel_space: int) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:CSPace \n
		Snippet: driver.configure.gprfMeasurement.acp.set_cspace(channel_space = 1) \n
		Defines the channel spacing, that is the center frequency difference of two adjacent channels. \n
			:param channel_space: Range: 100 Hz to 4 MHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(channel_space)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:ACP:CSPace {param}')

	def get_mbwidth(self) -> List[int]:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:MBWidth \n
		Snippet: value: List[int] = driver.configure.gprfMeasurement.acp.get_mbwidth() \n
		Defines the width of the measurement filter used to measure the channel power. The maximum allowed value is limited by
		the channel spacing, see method RsCma.Configure.GprfMeasurement.Acp.cspace. \n
			:return: meas_band_width: Range: 100 Hz to ChannelSpace, Unit: Hz
		"""
		response = self._core.io.query_bin_or_ascii_int_list('CONFigure:GPRF:MEASurement<Instance>:ACP:MBWidth?')
		return response

	def set_mbwidth(self, meas_band_width: List[int]) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:MBWidth \n
		Snippet: driver.configure.gprfMeasurement.acp.set_mbwidth(meas_band_width = [1, 2, 3]) \n
		Defines the width of the measurement filter used to measure the channel power. The maximum allowed value is limited by
		the channel spacing, see method RsCma.Configure.GprfMeasurement.Acp.cspace. \n
			:param meas_band_width: Range: 100 Hz to ChannelSpace, Unit: Hz
		"""
		param = Conversions.list_to_csv_str(meas_band_width)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:ACP:MBWidth {param}')

	# noinspection PyTypeChecker
	def get_offset(self) -> enums.AcpOffset:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:OFFSet \n
		Snippet: value: enums.AcpOffset = driver.configure.gprfMeasurement.acp.get_offset() \n
		Specifies an offset, moving the designated channel center frequency relative to the RF carrier center frequency. \n
			:return: offset: NONE | USB | LSB NONE No offset, for example for FM, PM, AM USB Positive offset, for USB modulation LSB Negative offset, for LSB modulation
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:ACP:OFFSet?')
		return Conversions.str_to_scalar_enum(response, enums.AcpOffset)

	def set_offset(self, offset: enums.AcpOffset) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:OFFSet \n
		Snippet: driver.configure.gprfMeasurement.acp.set_offset(offset = enums.AcpOffset.LSB) \n
		Specifies an offset, moving the designated channel center frequency relative to the RF carrier center frequency. \n
			:param offset: NONE | USB | LSB NONE No offset, for example for FM, PM, AM USB Positive offset, for USB modulation LSB Negative offset, for LSB modulation
		"""
		param = Conversions.enum_scalar_to_str(offset, enums.AcpOffset)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:ACP:OFFSet {param}')

	def clone(self) -> 'Acp':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Acp(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fft:
	"""Fft commands group definition. 5 total commands, 1 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fft", core, parent)

	@property
	def marker(self):
		"""marker commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_marker'):
			from .Fft_.Marker import Marker
			self._marker = Marker(self._core, self._base)
		return self._marker

	# noinspection PyTypeChecker
	def get_span(self) -> enums.FftSpan:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:FFT:SPAN \n
		Snippet: value: enums.FftSpan = driver.configure.afRf.measurement.multiEval.fft.get_span() \n
		No command help available \n
			:return: span: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:FFT:SPAN?')
		return Conversions.str_to_scalar_enum(response, enums.FftSpan)

	def set_span(self, span: enums.FftSpan) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:FFT:SPAN \n
		Snippet: driver.configure.afRf.measurement.multiEval.fft.set_span(span = enums.FftSpan.SP1) \n
		No command help available \n
			:param span: No help available
		"""
		param = Conversions.enum_scalar_to_str(span, enums.FftSpan)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:FFT:SPAN {param}')

	# noinspection PyTypeChecker
	def get_length(self) -> enums.FftLength:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:FFT:LENGth \n
		Snippet: value: enums.FftLength = driver.configure.afRf.measurement.multiEval.fft.get_length() \n
		No command help available \n
			:return: length: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:FFT:LENGth?')
		return Conversions.str_to_scalar_enum(response, enums.FftLength)

	def set_length(self, length: enums.FftLength) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:FFT:LENGth \n
		Snippet: driver.configure.afRf.measurement.multiEval.fft.set_length(length = enums.FftLength.F16K) \n
		No command help available \n
			:param length: No help available
		"""
		param = Conversions.enum_scalar_to_str(length, enums.FftLength)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:FFT:LENGth {param}')

	# noinspection PyTypeChecker
	def get_window(self) -> enums.FftWindowType:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:FFT:WINDow \n
		Snippet: value: enums.FftWindowType = driver.configure.afRf.measurement.multiEval.fft.get_window() \n
		Selects the window function to be applied before the fast Fourier transformation. \n
			:return: type_py: RECTangle | HAMMing | HANN | BLHA | FLTP RECTangle, HAMMing, HANN Rectangular / Hamming / Hann window BLHA Blackman-Harris window FLTP Flat-Top window
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:FFT:WINDow?')
		return Conversions.str_to_scalar_enum(response, enums.FftWindowType)

	def set_window(self, type_py: enums.FftWindowType) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:FFT:WINDow \n
		Snippet: driver.configure.afRf.measurement.multiEval.fft.set_window(type_py = enums.FftWindowType.BLHA) \n
		Selects the window function to be applied before the fast Fourier transformation. \n
			:param type_py: RECTangle | HAMMing | HANN | BLHA | FLTP RECTangle, HAMMing, HANN Rectangular / Hamming / Hann window BLHA Blackman-Harris window FLTP Flat-Top window
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.FftWindowType)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:FFT:WINDow {param}')

	def clone(self) -> 'Fft':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Fft(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Acp:
	"""Acp commands group definition. 38 total commands, 4 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("acp", core, parent)

	@property
	def state(self):
		"""state commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .Acp_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def aclr(self):
		"""aclr commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_aclr'):
			from .Acp_.Aclr import Aclr
			self._aclr = Aclr(self._core, self._base)
		return self._aclr

	@property
	def power(self):
		"""power commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Acp_.Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def obw(self):
		"""obw commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_obw'):
			from .Acp_.Obw import Obw
			self._obw = Obw(self._core, self._base)
		return self._obw

	def initiate(self) -> None:
		"""SCPI: INITiate:GPRF:MEASurement<Instance>:ACP \n
		Snippet: driver.gprfMeasurement.acp.initiate() \n
		Starts or continues the ACP measurement. \n
		"""
		self._core.io.write(f'INITiate:GPRF:MEASurement<Instance>:ACP')

	def initiate_with_opc(self) -> None:
		"""SCPI: INITiate:GPRF:MEASurement<Instance>:ACP \n
		Snippet: driver.gprfMeasurement.acp.initiate_with_opc() \n
		Starts or continues the ACP measurement. \n
		Same as initiate, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'INITiate:GPRF:MEASurement<Instance>:ACP')

	def stop(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:ACP \n
		Snippet: driver.gprfMeasurement.acp.stop() \n
		Pauses the ACP measurement. \n
		"""
		self._core.io.write(f'STOP:GPRF:MEASurement<Instance>:ACP')

	def stop_with_opc(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:ACP \n
		Snippet: driver.gprfMeasurement.acp.stop_with_opc() \n
		Pauses the ACP measurement. \n
		Same as stop, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'STOP:GPRF:MEASurement<Instance>:ACP')

	def abort(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:ACP \n
		Snippet: driver.gprfMeasurement.acp.abort() \n
		Stops the ACP measurement. \n
		"""
		self._core.io.write(f'ABORt:GPRF:MEASurement<Instance>:ACP')

	def abort_with_opc(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:ACP \n
		Snippet: driver.gprfMeasurement.acp.abort_with_opc() \n
		Stops the ACP measurement. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'ABORt:GPRF:MEASurement<Instance>:ACP')

	def clone(self) -> 'Acp':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Acp(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPy:
	"""FilterPy commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("filterPy", core, parent)

	@property
	def notch(self):
		"""notch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_notch'):
			from .FilterPy_.Notch import Notch
			self._notch = Notch(self._core, self._base)
		return self._notch

	def get_disable(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FILTer:DISable \n
		Snippet: value: bool = driver.configure.afRf.measurement.filterPy.get_disable() \n
		No command help available \n
			:return: disable: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:FILTer:DISable?')
		return Conversions.str_to_bool(response)

	def set_disable(self, disable: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FILTer:DISable \n
		Snippet: driver.configure.afRf.measurement.filterPy.set_disable(disable = False) \n
		No command help available \n
			:param disable: No help available
		"""
		param = Conversions.bool_to_str(disable)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FILTer:DISable {param}')

	def clone(self) -> 'FilterPy':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FilterPy(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, gen_control: bool) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:STATe \n
		Snippet: driver.source.avionics.generator.markerBeacon.state.set(gen_control = False) \n
		Starts or stops the VOR generator or queries its state. \n
			:param gen_control: ON | OFF ON Starts the generator OFF Stops the generator
		"""
		param = Conversions.bool_to_str(gen_control)
		self._core.io.write_with_opc(f'SOURce:AVIonics:GENerator<Instance>:MBEacon:STATe {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.GeneratorState:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:STATe \n
		Snippet: value: enums.GeneratorState = driver.source.avionics.generator.markerBeacon.state.get() \n
		Starts or stops the VOR generator or queries its state. \n
			:return: gen_state: OFF | ON | PENDing OFF Generator is off ON Generator is running PENDing Start or stop of generator is ongoing"""
		response = self._core.io.query_str_with_opc(f'SOURce:AVIonics:GENerator<Instance>:MBEacon:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.GeneratorState)

	# noinspection PyTypeChecker
	def get_all(self) -> List[enums.GeneratorState]:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:STATe:ALL \n
		Snippet: value: List[enums.GeneratorState] = driver.source.avionics.generator.markerBeacon.state.get_all() \n
		No command help available \n
			:return: all_states: No help available
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:MBEacon:STATe:ALL?')
		return Conversions.str_to_list_enum(response, enums.GeneratorState)



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Types import DataType
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class All:
	"""All commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("all", core, parent)

	def get(self, filter_py: str = None, mode: enums.ExpressionMode = None) -> List[str]:
		"""SCPI: STATus:CONDition:BITS:ALL \n
		Snippet: value: List[str] = driver.status.condition.bits.all.get(filter_py = '1', mode = enums.ExpressionMode.REGex) \n
		No command help available \n
			:param filter_py: No help available
			:param mode: No help available
			:return: bit: No help available"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('filter_py', filter_py, DataType.String, True), ArgSingle('mode', mode, DataType.Enum, True))
		response = self._core.io.query_str(f'STATus:CONDition:BITS:ALL? {param}'.rstrip())
		return Conversions.str_to_str_list(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dialing:
	"""Dialing commands group definition. 3 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dialing", core, parent)

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Dialing_.Mode import Mode
			self._mode = Mode(self._core, self._base)
		return self._mode

	def start(self, internalGen=repcap.InternalGen.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:DIALing:STARt \n
		Snippet: driver.source.afRf.generator.internalGenerator.dialing.start(internalGen = repcap.InternalGen.Default) \n
		No command help available \n
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')"""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:DIALing:STARt')

	def start_with_opc(self, internalGen=repcap.InternalGen.Default) -> None:
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:DIALing:STARt \n
		Snippet: driver.source.afRf.generator.internalGenerator.dialing.start_with_opc(internalGen = repcap.InternalGen.Default) \n
		No command help available \n
		Same as start, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')"""
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:DIALing:STARt')

	def set(self, dialing_state: bool, internalGen=repcap.InternalGen.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:DIALing \n
		Snippet: driver.source.afRf.generator.internalGenerator.dialing.set(dialing_state = False, internalGen = repcap.InternalGen.Default) \n
		Starts or stops dialing a digit sequence. This command is relevant for dialing modes like SELCAL, DTMF, SelCall or free
		dialing. For dialing measurements, ensure a delay between starting the measurement and dialing the sequence via this
		command. Otherwise, the measurement misses the first tones and fails. Required delays depending on the input path: for AF
		/ SPDIF path 400 ms, for RF path 800 ms. \n
			:param dialing_state: OFF | ON
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')"""
		param = Conversions.bool_to_str(dialing_state)
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:DIALing {param}')

	def get(self, internalGen=repcap.InternalGen.Default) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:DIALing \n
		Snippet: value: bool = driver.source.afRf.generator.internalGenerator.dialing.get(internalGen = repcap.InternalGen.Default) \n
		Starts or stops dialing a digit sequence. This command is relevant for dialing modes like SELCAL, DTMF, SelCall or free
		dialing. For dialing measurements, ensure a delay between starting the measurement and dialing the sequence via this
		command. Otherwise, the measurement misses the first tones and fails. Required delays depending on the input path: for AF
		/ SPDIF path 400 ms, for RF path 800 ms. \n
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')
			:return: dialing_state: OFF | ON"""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		response = self._core.io.query_str(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:DIALing?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'Dialing':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dialing(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Generator:
	"""Generator commands group definition. 21 total commands, 5 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("generator", core, parent)

	@property
	def reliability(self):
		"""reliability commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_reliability'):
			from .Generator_.Reliability import Reliability
			self._reliability = Reliability(self._core, self._base)
		return self._reliability

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_state'):
			from .Generator_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def digital(self):
		"""digital commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_digital'):
			from .Generator_.Digital import Digital
			self._digital = Digital(self._core, self._base)
		return self._digital

	@property
	def rfSettings(self):
		"""rfSettings commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_rfSettings'):
			from .Generator_.RfSettings import RfSettings
			self._rfSettings = RfSettings(self._core, self._base)
		return self._rfSettings

	@property
	def arb(self):
		"""arb commands group. 2 Sub-classes, 6 commands."""
		if not hasattr(self, '_arb'):
			from .Generator_.Arb import Arb
			self._arb = Arb(self._core, self._base)
		return self._arb

	# noinspection PyTypeChecker
	def get_dsource(self) -> enums.DigitalSource:
		"""SCPI: SOURce:XRT:GENerator<Instance>:DSOurce \n
		Snippet: value: enums.DigitalSource = driver.source.xrt.generator.get_dsource() \n
		No command help available \n
			:return: dsource: No help available
		"""
		response = self._core.io.query_str('SOURce:XRT:GENerator<Instance>:DSOurce?')
		return Conversions.str_to_scalar_enum(response, enums.DigitalSource)

	def set_dsource(self, dsource: enums.DigitalSource) -> None:
		"""SCPI: SOURce:XRT:GENerator<Instance>:DSOurce \n
		Snippet: driver.source.xrt.generator.set_dsource(dsource = enums.DigitalSource.ARB) \n
		No command help available \n
			:param dsource: No help available
		"""
		param = Conversions.enum_scalar_to_str(dsource, enums.DigitalSource)
		self._core.io.write(f'SOURce:XRT:GENerator<Instance>:DSOurce {param}')

	def clone(self) -> 'Generator':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Generator(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Generator:
	"""Generator commands group definition. 240 total commands, 23 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("generator", core, parent)

	@property
	def reliability(self):
		"""reliability commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_reliability'):
			from .Generator_.Reliability import Reliability
			self._reliability = Reliability(self._core, self._base)
		return self._reliability

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_state'):
			from .Generator_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def digital(self):
		"""digital commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_digital'):
			from .Generator_.Digital import Digital
			self._digital = Digital(self._core, self._base)
		return self._digital

	@property
	def dmr(self):
		"""dmr commands group. 0 Sub-classes, 11 commands."""
		if not hasattr(self, '_dmr'):
			from .Generator_.Dmr import Dmr
			self._dmr = Dmr(self._core, self._base)
		return self._dmr

	@property
	def nxdn(self):
		"""nxdn commands group. 0 Sub-classes, 12 commands."""
		if not hasattr(self, '_nxdn'):
			from .Generator_.Nxdn import Nxdn
			self._nxdn = Nxdn(self._core, self._base)
		return self._nxdn

	@property
	def pocsag(self):
		"""pocsag commands group. 0 Sub-classes, 8 commands."""
		if not hasattr(self, '_pocsag'):
			from .Generator_.Pocsag import Pocsag
			self._pocsag = Pocsag(self._core, self._base)
		return self._pocsag

	@property
	def ptFive(self):
		"""ptFive commands group. 2 Sub-classes, 6 commands."""
		if not hasattr(self, '_ptFive'):
			from .Generator_.PtFive import PtFive
			self._ptFive = PtFive(self._core, self._base)
		return self._ptFive

	@property
	def userDefined(self):
		"""userDefined commands group. 0 Sub-classes, 12 commands."""
		if not hasattr(self, '_userDefined'):
			from .Generator_.UserDefined import UserDefined
			self._userDefined = UserDefined(self._core, self._base)
		return self._userDefined

	@property
	def zigbee(self):
		"""zigbee commands group. 0 Sub-classes, 9 commands."""
		if not hasattr(self, '_zigbee'):
			from .Generator_.Zigbee import Zigbee
			self._zigbee = Zigbee(self._core, self._base)
		return self._zigbee

	@property
	def dpmr(self):
		"""dpmr commands group. 1 Sub-classes, 11 commands."""
		if not hasattr(self, '_dpmr'):
			from .Generator_.Dpmr import Dpmr
			self._dpmr = Dpmr(self._core, self._base)
		return self._dpmr

	@property
	def voip(self):
		"""voip commands group. 3 Sub-classes, 7 commands."""
		if not hasattr(self, '_voip'):
			from .Generator_.Voip import Voip
			self._voip = Voip(self._core, self._base)
		return self._voip

	@property
	def rfSettings(self):
		"""rfSettings commands group. 2 Sub-classes, 9 commands."""
		if not hasattr(self, '_rfSettings'):
			from .Generator_.RfSettings import RfSettings
			self._rfSettings = RfSettings(self._core, self._base)
		return self._rfSettings

	@property
	def modulator(self):
		"""modulator commands group. 1 Sub-classes, 5 commands."""
		if not hasattr(self, '_modulator'):
			from .Generator_.Modulator import Modulator
			self._modulator = Modulator(self._core, self._base)
		return self._modulator

	@property
	def filterPy(self):
		"""filterPy commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_filterPy'):
			from .Generator_.FilterPy import FilterPy
			self._filterPy = FilterPy(self._core, self._base)
		return self._filterPy

	@property
	def internalGenerator(self):
		"""internalGenerator commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_internalGenerator'):
			from .Generator_.InternalGenerator import InternalGenerator
			self._internalGenerator = InternalGenerator(self._core, self._base)
		return self._internalGenerator

	@property
	def dialing(self):
		"""dialing commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_dialing'):
			from .Generator_.Dialing import Dialing
			self._dialing = Dialing(self._core, self._base)
		return self._dialing

	@property
	def audioInput(self):
		"""audioInput commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_audioInput'):
			from .Generator_.AudioInput import AudioInput
			self._audioInput = AudioInput(self._core, self._base)
		return self._audioInput

	@property
	def audioOutput(self):
		"""audioOutput commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_audioOutput'):
			from .Generator_.AudioOutput import AudioOutput
			self._audioOutput = AudioOutput(self._core, self._base)
		return self._audioOutput

	@property
	def sout(self):
		"""sout commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_sout'):
			from .Generator_.Sout import Sout
			self._sout = Sout(self._core, self._base)
		return self._sout

	@property
	def tones(self):
		"""tones commands group. 3 Sub-classes, 4 commands."""
		if not hasattr(self, '_tones'):
			from .Generator_.Tones import Tones
			self._tones = Tones(self._core, self._base)
		return self._tones

	@property
	def cdefinition(self):
		"""cdefinition commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_cdefinition'):
			from .Generator_.Cdefinition import Cdefinition
			self._cdefinition = Cdefinition(self._core, self._base)
		return self._cdefinition

	@property
	def arb(self):
		"""arb commands group. 3 Sub-classes, 6 commands."""
		if not hasattr(self, '_arb'):
			from .Generator_.Arb import Arb
			self._arb = Arb(self._core, self._base)
		return self._arb

	@property
	def interferer(self):
		"""interferer commands group. 3 Sub-classes, 3 commands."""
		if not hasattr(self, '_interferer'):
			from .Generator_.Interferer import Interferer
			self._interferer = Interferer(self._core, self._base)
		return self._interferer

	# noinspection PyTypeChecker
	def get_dsource(self) -> enums.DigitalSource:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DSOurce \n
		Snippet: value: enums.DigitalSource = driver.source.afRf.generator.get_dsource() \n
		Selects the data source for digital scenarios. \n
			:return: dsource: DMR | ARB | NXDN | POCSag | P25 | UDEFined | ZIGBee
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DSOurce?')
		return Conversions.str_to_scalar_enum(response, enums.DigitalSource)

	def set_dsource(self, dsource: enums.DigitalSource) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DSOurce \n
		Snippet: driver.source.afRf.generator.set_dsource(dsource = enums.DigitalSource.ARB) \n
		Selects the data source for digital scenarios. \n
			:param dsource: DMR | ARB | NXDN | POCSag | P25 | UDEFined | ZIGBee
		"""
		param = Conversions.enum_scalar_to_str(dsource, enums.DigitalSource)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DSOurce {param}')

	# noinspection PyTypeChecker
	def get_mscheme(self) -> enums.ModulationScheme:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:MSCHeme \n
		Snippet: value: enums.ModulationScheme = driver.source.afRf.generator.get_mscheme() \n
		Selects the RF signal mode (modulation scheme) for analog scenarios. \n
			:return: mod_scheme: FMSTereo | FM | AM | USB | LSB | PM | CW | ARB FMSTereo FM stereo multiplex signal FM, PM, AM Frequency / phase / amplitude modulation USB, LSB Single sideband modulation, upper / lower sideband CW Constant wave signal (unmodulated RF carrier) ARB Waveform file (ARB file)
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:MSCHeme?')
		return Conversions.str_to_scalar_enum(response, enums.ModulationScheme)

	def set_mscheme(self, mod_scheme: enums.ModulationScheme) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:MSCHeme \n
		Snippet: driver.source.afRf.generator.set_mscheme(mod_scheme = enums.ModulationScheme.AM) \n
		Selects the RF signal mode (modulation scheme) for analog scenarios. \n
			:param mod_scheme: FMSTereo | FM | AM | USB | LSB | PM | CW | ARB FMSTereo FM stereo multiplex signal FM, PM, AM Frequency / phase / amplitude modulation USB, LSB Single sideband modulation, upper / lower sideband CW Constant wave signal (unmodulated RF carrier) ARB Waveform file (ARB file)
		"""
		param = Conversions.enum_scalar_to_str(mod_scheme, enums.ModulationScheme)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:MSCHeme {param}')

	def clone(self) -> 'Generator':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Generator(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RifBandwidth:
	"""RifBandwidth commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rifBandwidth", core, parent)

	# noinspection PyTypeChecker
	class BwDisplaceStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON
			- Lower: float: Range: 1 Hz to 100000 Hz, Unit: Hz
			- Upper: float: Range: 1000 Hz to 1 MHz, Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_bw_displace(self) -> BwDisplaceStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RIFBandwidth:BWDisplace \n
		Snippet: value: BwDisplaceStruct = driver.configure.afRf.measurement.searchRoutines.limit.rifBandwidth.get_bw_displace() \n
		Enables a limit check and sets limits for the RX bandwidth / RF signal displacement bandwidth. \n
			:return: structure: for return value, see the help for BwDisplaceStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RIFBandwidth:BWDisplace?', self.__class__.BwDisplaceStruct())

	def set_bw_displace(self, value: BwDisplaceStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RIFBandwidth:BWDisplace \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.limit.rifBandwidth.set_bw_displace(value = BwDisplaceStruct()) \n
		Enables a limit check and sets limits for the RX bandwidth / RF signal displacement bandwidth. \n
			:param value: see the help for BwDisplaceStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RIFBandwidth:BWDisplace', value)

	# noinspection PyTypeChecker
	class FoffsetStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON
			- Upper: float: Range: 1 Hz to 50000 Hz, Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Upper: float = None

	def get_foffset(self) -> FoffsetStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RIFBandwidth:FOFFset \n
		Snippet: value: FoffsetStruct = driver.configure.afRf.measurement.searchRoutines.limit.rifBandwidth.get_foffset() \n
		Sets the upper limit for the center frequency offset. \n
			:return: structure: for return value, see the help for FoffsetStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RIFBandwidth:FOFFset?', self.__class__.FoffsetStruct())

	def set_foffset(self, value: FoffsetStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RIFBandwidth:FOFFset \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.limit.rifBandwidth.set_foffset(value = FoffsetStruct()) \n
		Sets the upper limit for the center frequency offset. \n
			:param value: see the help for FoffsetStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RIFBandwidth:FOFFset', value)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Bandpass:
	"""Bandpass commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bandpass", core, parent)

	def get_bandwidth(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:POWer:FILTer:BANDpass:BWIDth \n
		Snippet: value: float = driver.configure.gprfMeasurement.power.filterPy.bandpass.get_bandwidth() \n
		Selects the bandwidth for the bandpass filter. \n
			:return: bandpass_bw: You can enter values between 1 kHz and 20 MHz. The setting is rounded to the closest of the following values: 1 / 2 / 3 / 5 / 10 / 20 / 30 / 50 / 100 / 200 / 300 / 500 kHz 1 / 1.08 / 2 / 2.7 / 3 / 4.5 / 5 / 9 / 10 / 13.5 / 18 / 20 / 40 MHz Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:POWer:FILTer:BANDpass:BWIDth?')
		return Conversions.str_to_float(response)

	def set_bandwidth(self, bandpass_bw: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:POWer:FILTer:BANDpass:BWIDth \n
		Snippet: driver.configure.gprfMeasurement.power.filterPy.bandpass.set_bandwidth(bandpass_bw = 1.0) \n
		Selects the bandwidth for the bandpass filter. \n
			:param bandpass_bw: You can enter values between 1 kHz and 20 MHz. The setting is rounded to the closest of the following values: 1 / 2 / 3 / 5 / 10 / 20 / 30 / 50 / 100 / 200 / 300 / 500 kHz 1 / 1.08 / 2 / 2.7 / 3 / 4.5 / 5 / 9 / 10 / 13.5 / 18 / 20 / 40 MHz Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(bandpass_bw)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:POWer:FILTer:BANDpass:BWIDth {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.ArgSingleSuppressed import ArgSingleSuppressed
from .......Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Current:
	"""Current commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("current", core, parent)

	def fetch(self) -> int:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:DATA:FSK:BERate:CURRent \n
		Snippet: value: int = driver.afRf.measurement.data.fsk.bitErrorRate.current.fetch() \n
		Fetches the bit error rate result. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: ber: Range: 0 to 100"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'FETCh:AFRF:MEASurement<Instance>:DATA:FSK:BERate:CURRent?', suppressed)
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mtones:
	"""Mtones commands group definition. 24 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mtones", core, parent)

	@property
	def audioInput(self):
		"""audioInput commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_audioInput'):
			from .Mtones_.AudioInput import AudioInput
			self._audioInput = AudioInput(self._core, self._base)
		return self._audioInput

	@property
	def spdifLeft(self):
		"""spdifLeft commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_spdifLeft'):
			from .Mtones_.SpdifLeft import SpdifLeft
			self._spdifLeft = SpdifLeft(self._core, self._base)
		return self._spdifLeft

	@property
	def spdifRight(self):
		"""spdifRight commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_spdifRight'):
			from .Mtones_.SpdifRight import SpdifRight
			self._spdifRight = SpdifRight(self._core, self._base)
		return self._spdifRight

	def clone(self) -> 'Mtones':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Mtones(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Hexadecimal:
	"""Hexadecimal commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("hexadecimal", core, parent)

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: No parameter help available
			- Symbols_Number: int: No parameter help available
			- Symbols: List[str]: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_int('Symbols_Number'),
			ArgStruct('Symbols', DataType.RawStringList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Symbols_Number: int = None
			self.Symbols: List[str] = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:VSE:MEASurement<Instance>:NXDN:SYMBols:HEXadecimal \n
		Snippet: value: ResultData = driver.vse.measurement.nxdn.symbols.hexadecimal.fetch() \n
		Queries the received symbols in hexadecimal format. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:VSE:MEASurement<Instance>:NXDN:SYMBols:HEXadecimal?', self.__class__.ResultData())

	def read(self) -> ResultData:
		"""SCPI: READ:VSE:MEASurement<Instance>:NXDN:SYMBols:HEXadecimal \n
		Snippet: value: ResultData = driver.vse.measurement.nxdn.symbols.hexadecimal.read() \n
		Queries the received symbols in hexadecimal format. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:VSE:MEASurement<Instance>:NXDN:SYMBols:HEXadecimal?', self.__class__.ResultData())



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Source:
	"""Source commands group definition. 336 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("source", core, parent)

	@property
	def afRf(self):
		"""afRf commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_afRf'):
			from .Source_.AfRf import AfRf
			self._afRf = AfRf(self._core, self._base)
		return self._afRf

	@property
	def xrt(self):
		"""xrt commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_xrt'):
			from .Source_.Xrt import Xrt
			self._xrt = Xrt(self._core, self._base)
		return self._xrt

	@property
	def avionics(self):
		"""avionics commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_avionics'):
			from .Source_.Avionics import Avionics
			self._avionics = Avionics(self._core, self._base)
		return self._avionics

	@property
	def base(self):
		"""base commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_base'):
			from .Source_.Base import Base
			self._base = Base(self._core, self._base)
		return self._base

	def clone(self) -> 'Source':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Source(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Limpedance:
	"""Limpedance commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("limpedance", core, parent)

	# noinspection PyTypeChecker
	class LimpedanceStruct(StructBase):
		"""Structure for setting input parameters. Fields: \n
			- Enable: bool: OFF | ON ON: Use the configured Impedance. OFF: Ignore the configured Impedance.
			- Impedance: float: Range: 1 Ω to 100E+6 Ω, Unit: Ω"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Impedance')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Impedance: float = None

	def set(self, structure: LimpedanceStruct, audioOutput=repcap.AudioOutput.Default) -> None:
		"""SCPI: CONFigure:BASE:AOUT<nr>:LIMPedance \n
		Snippet: driver.configure.base.audioOutput.limpedance.set(value = [PROPERTY_STRUCT_NAME](), audioOutput = repcap.AudioOutput.Default) \n
		Configures the impedance 'R Load'. \n
			:param structure: for set value, see the help for LimpedanceStruct structure arguments.
			:param audioOutput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioOutput')"""
		audioOutput_cmd_val = self._base.get_repcap_cmd_value(audioOutput, repcap.AudioOutput)
		self._core.io.write_struct(f'CONFigure:BASE:AOUT{audioOutput_cmd_val}:LIMPedance', structure)

	def get(self, audioOutput=repcap.AudioOutput.Default) -> LimpedanceStruct:
		"""SCPI: CONFigure:BASE:AOUT<nr>:LIMPedance \n
		Snippet: value: LimpedanceStruct = driver.configure.base.audioOutput.limpedance.get(audioOutput = repcap.AudioOutput.Default) \n
		Configures the impedance 'R Load'. \n
			:param audioOutput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioOutput')
			:return: structure: for return value, see the help for LimpedanceStruct structure arguments."""
		audioOutput_cmd_val = self._base.get_repcap_cmd_value(audioOutput, repcap.AudioOutput)
		return self._core.io.query_struct(f'CONFigure:BASE:AOUT{audioOutput_cmd_val}:LIMPedance?', self.__class__.LimpedanceStruct())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Spectrum:
	"""Spectrum commands group definition. 7 total commands, 1 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("spectrum", core, parent)

	@property
	def catalog(self):
		"""catalog commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_catalog'):
			from .Spectrum_.Catalog import Catalog
			self._catalog = Catalog(self._core, self._base)
		return self._catalog

	def get_threshold(self) -> float:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:SPECtrum:THReshold \n
		Snippet: value: float = driver.trigger.gprfMeasurement.spectrum.get_threshold() \n
		Defines the trigger threshold for trigger source 'Video'. \n
			:return: threshold: Range: -50 dB to 0 dB, Unit: dB (full scale, i.e. relative to expected power minus external attenuation)
		"""
		response = self._core.io.query_str('TRIGger:GPRF:MEASurement<Instance>:SPECtrum:THReshold?')
		return Conversions.str_to_float(response)

	def set_threshold(self, threshold: float) -> None:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:SPECtrum:THReshold \n
		Snippet: driver.trigger.gprfMeasurement.spectrum.set_threshold(threshold = 1.0) \n
		Defines the trigger threshold for trigger source 'Video'. \n
			:param threshold: Range: -50 dB to 0 dB, Unit: dB (full scale, i.e. relative to expected power minus external attenuation)
		"""
		param = Conversions.decimal_value_to_str(threshold)
		self._core.io.write(f'TRIGger:GPRF:MEASurement<Instance>:SPECtrum:THReshold {param}')

	def get_source(self) -> str:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:SPECtrum:SOURce \n
		Snippet: value: str = driver.trigger.gprfMeasurement.spectrum.get_source() \n
		Selects a trigger event source for spectrum analysis. To query a list of all supported sources, use method RsCma.Trigger.
		GprfMeasurement.Spectrum.Catalog.source. \n
			:return: source: Source as string, examples: 'Free Run' Immediate start without trigger signal 'Video' Trigger by video power steps 'Base1: External TRIG In' Trigger signal at connector TRIG IN 'AFRF Gen1: ...' Trigger by processed waveform file
		"""
		response = self._core.io.query_str('TRIGger:GPRF:MEASurement<Instance>:SPECtrum:SOURce?')
		return trim_str_response(response)

	def set_source(self, source: str) -> None:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:SPECtrum:SOURce \n
		Snippet: driver.trigger.gprfMeasurement.spectrum.set_source(source = '1') \n
		Selects a trigger event source for spectrum analysis. To query a list of all supported sources, use method RsCma.Trigger.
		GprfMeasurement.Spectrum.Catalog.source. \n
			:param source: Source as string, examples: 'Free Run' Immediate start without trigger signal 'Video' Trigger by video power steps 'Base1: External TRIG In' Trigger signal at connector TRIG IN 'AFRF Gen1: ...' Trigger by processed waveform file
		"""
		param = Conversions.value_to_quoted_str(source)
		self._core.io.write(f'TRIGger:GPRF:MEASurement<Instance>:SPECtrum:SOURce {param}')

	# noinspection PyTypeChecker
	def get_slope(self) -> enums.SignalSlopeExt:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:SPECtrum:SLOPe \n
		Snippet: value: enums.SignalSlopeExt = driver.trigger.gprfMeasurement.spectrum.get_slope() \n
		Selects whether the trigger event is generated at the rising or at the falling edge of the trigger pulse. This command is
		relevant for the trigger source 'Video'. \n
			:return: slope: REDGe | FEDGe | RISing | FALLing REDGe, RISing Rising edge FEDGe, FALLing Falling edge
		"""
		response = self._core.io.query_str('TRIGger:GPRF:MEASurement<Instance>:SPECtrum:SLOPe?')
		return Conversions.str_to_scalar_enum(response, enums.SignalSlopeExt)

	def set_slope(self, slope: enums.SignalSlopeExt) -> None:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:SPECtrum:SLOPe \n
		Snippet: driver.trigger.gprfMeasurement.spectrum.set_slope(slope = enums.SignalSlopeExt.FALLing) \n
		Selects whether the trigger event is generated at the rising or at the falling edge of the trigger pulse. This command is
		relevant for the trigger source 'Video'. \n
			:param slope: REDGe | FEDGe | RISing | FALLing REDGe, RISing Rising edge FEDGe, FALLing Falling edge
		"""
		param = Conversions.enum_scalar_to_str(slope, enums.SignalSlopeExt)
		self._core.io.write(f'TRIGger:GPRF:MEASurement<Instance>:SPECtrum:SLOPe {param}')

	def get_mgap(self) -> float:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:SPECtrum:MGAP \n
		Snippet: value: float = driver.trigger.gprfMeasurement.spectrum.get_mgap() \n
		Defines the minimum duration of the power-down periods (gaps) between two triggered power pulses. This setting is
		relevant for trigger source 'Video'. \n
			:return: minimum_gap: Range: 0 s to 0.01 s, Unit: s
		"""
		response = self._core.io.query_str('TRIGger:GPRF:MEASurement<Instance>:SPECtrum:MGAP?')
		return Conversions.str_to_float(response)

	def set_mgap(self, minimum_gap: float) -> None:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:SPECtrum:MGAP \n
		Snippet: driver.trigger.gprfMeasurement.spectrum.set_mgap(minimum_gap = 1.0) \n
		Defines the minimum duration of the power-down periods (gaps) between two triggered power pulses. This setting is
		relevant for trigger source 'Video'. \n
			:param minimum_gap: Range: 0 s to 0.01 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(minimum_gap)
		self._core.io.write(f'TRIGger:GPRF:MEASurement<Instance>:SPECtrum:MGAP {param}')

	def get_offset(self) -> float:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:SPECtrum:OFFSet \n
		Snippet: value: float = driver.trigger.gprfMeasurement.spectrum.get_offset() \n
		Defines a delay time for triggered zero span measurements. The trigger offset delays the start of the measurement
		relative to the trigger event. This command is relevant for the trigger source 'Video' and for trigger signals at TRIG IN. \n
			:return: trigger_offset: Range: -0.5 s to 0.5 s, Unit: s
		"""
		response = self._core.io.query_str('TRIGger:GPRF:MEASurement<Instance>:SPECtrum:OFFSet?')
		return Conversions.str_to_float(response)

	def set_offset(self, trigger_offset: float) -> None:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:SPECtrum:OFFSet \n
		Snippet: driver.trigger.gprfMeasurement.spectrum.set_offset(trigger_offset = 1.0) \n
		Defines a delay time for triggered zero span measurements. The trigger offset delays the start of the measurement
		relative to the trigger event. This command is relevant for the trigger source 'Video' and for trigger signals at TRIG IN. \n
			:param trigger_offset: Range: -0.5 s to 0.5 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(trigger_offset)
		self._core.io.write(f'TRIGger:GPRF:MEASurement<Instance>:SPECtrum:OFFSet {param}')

	def get_timeout(self) -> float:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:SPECtrum:TOUT \n
		Snippet: value: float = driver.trigger.gprfMeasurement.spectrum.get_timeout() \n
		Specifies the time after which an initiated measurement must have received a trigger event. If no trigger event is
		received, the measurement is stopped in remote control mode. In manual operation mode, a trigger timeout is indicated.
		This setting is relevant for the trigger source 'Video' and for trigger signals at TRIG IN. \n
			:return: trigger_timeout: Range: 0.01 s to 300 s, Unit: s
		"""
		response = self._core.io.query_str('TRIGger:GPRF:MEASurement<Instance>:SPECtrum:TOUT?')
		return Conversions.str_to_float(response)

	def set_timeout(self, trigger_timeout: float) -> None:
		"""SCPI: TRIGger:GPRF:MEASurement<Instance>:SPECtrum:TOUT \n
		Snippet: driver.trigger.gprfMeasurement.spectrum.set_timeout(trigger_timeout = 1.0) \n
		Specifies the time after which an initiated measurement must have received a trigger event. If no trigger event is
		received, the measurement is stopped in remote control mode. In manual operation mode, a trigger timeout is indicated.
		This setting is relevant for the trigger source 'Video' and for trigger signals at TRIG IN. \n
			:param trigger_timeout: Range: 0.01 s to 300 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(trigger_timeout)
		self._core.io.write(f'TRIGger:GPRF:MEASurement<Instance>:SPECtrum:TOUT {param}')

	def clone(self) -> 'Spectrum':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Spectrum(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pdeviation:
	"""Pdeviation commands group definition. 12 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pdeviation", core, parent)

	@property
	def current(self):
		"""current commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_current'):
			from .Pdeviation_.Current import Current
			self._current = Current(self._core, self._base)
		return self._current

	@property
	def average(self):
		"""average commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_average'):
			from .Pdeviation_.Average import Average
			self._average = Average(self._core, self._base)
		return self._average

	@property
	def maximum(self):
		"""maximum commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_maximum'):
			from .Pdeviation_.Maximum import Maximum
			self._maximum = Maximum(self._core, self._base)
		return self._maximum

	@property
	def deviation(self):
		"""deviation commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_deviation'):
			from .Pdeviation_.Deviation import Deviation
			self._deviation = Deviation(self._core, self._base)
		return self._deviation

	def clone(self) -> 'Pdeviation':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Pdeviation(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Value:
	"""Value commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("value", core, parent)

	# noinspection PyTypeChecker
	def get_enable(self) -> enums.DirPwrSensorRevValue:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:VALue:ENABle \n
		Snippet: value: enums.DirPwrSensorRevValue = driver.configure.gprfMeasurement.nrt.reverse.value.get_enable() \n
		Selects the reverse result to be measured.
			INTRO_CMD_HELP: The effect of the value RPWR depends on the value set via the command method RsCma.Configure.GprfMeasurement.Nrt.Forward.Value.enable: \n
			- FPWR or PEP: RPWR selects the reverse power result
			- CFAC or CCDF: RPWR selects the forward power result \n
			:return: value: RPWR | RLOS | REFL | SWR RPWR Reverse power or forward power RLOS Return loss REFL Reflection SWR Standing wave ratio
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:VALue:ENABle?')
		return Conversions.str_to_scalar_enum(response, enums.DirPwrSensorRevValue)

	def set_enable(self, value: enums.DirPwrSensorRevValue) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:VALue:ENABle \n
		Snippet: driver.configure.gprfMeasurement.nrt.reverse.value.set_enable(value = enums.DirPwrSensorRevValue.REFL) \n
		Selects the reverse result to be measured.
			INTRO_CMD_HELP: The effect of the value RPWR depends on the value set via the command method RsCma.Configure.GprfMeasurement.Nrt.Forward.Value.enable: \n
			- FPWR or PEP: RPWR selects the reverse power result
			- CFAC or CCDF: RPWR selects the forward power result \n
			:param value: RPWR | RLOS | REFL | SWR RPWR Reverse power or forward power RLOS Return loss REFL Reflection SWR Standing wave ratio
		"""
		param = Conversions.enum_scalar_to_str(value, enums.DirPwrSensorRevValue)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:NRT:REVerse:VALue:ENABle {param}')



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MultiTone:
	"""MultiTone commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("multiTone", core, parent)

	def get_tlevel(self) -> List[float]:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator:FOURth:MTONe:TLEVel \n
		Snippet: value: List[float] = driver.source.afRf.generator.internalGenerator.fourth.multiTone.get_tlevel() \n
		No command help available \n
			:return: tlevel: No help available
		"""
		response = self._core.io.query_bin_or_ascii_float_list('SOURce:AFRF:GENerator<Instance>:IGENerator:FOURth:MTONe:TLEVel?')
		return response

	def set_tlevel(self, tlevel: List[float]) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator:FOURth:MTONe:TLEVel \n
		Snippet: driver.source.afRf.generator.internalGenerator.fourth.multiTone.set_tlevel(tlevel = [1.1, 2.2, 3.3]) \n
		No command help available \n
			:param tlevel: No help available
		"""
		param = Conversions.list_to_csv_str(tlevel)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IGENerator:FOURth:MTONe:TLEVel {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfSettings:
	"""RfSettings commands group definition. 3 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rfSettings", core, parent)

	@property
	def rfOut(self):
		"""rfOut commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rfOut'):
			from .RfSettings_.RfOut import RfOut
			self._rfOut = RfOut(self._core, self._base)
		return self._rfOut

	def get_frequency(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:RFSettings:FREQuency \n
		Snippet: value: float = driver.source.avionics.generator.markerBeacon.rfSettings.get_frequency() \n
		Sets the center frequency of the unmodulated RF carrier. \n
			:return: freq: Range: 100 kHz to 3 GHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:MBEacon:RFSettings:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, freq: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:RFSettings:FREQuency \n
		Snippet: driver.source.avionics.generator.markerBeacon.rfSettings.set_frequency(freq = 1.0) \n
		Sets the center frequency of the unmodulated RF carrier. \n
			:param freq: Range: 100 kHz to 3 GHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(freq)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:MBEacon:RFSettings:FREQuency {param}')

	def get_level(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:RFSettings:LEVel \n
		Snippet: value: float = driver.source.avionics.generator.markerBeacon.rfSettings.get_level() \n
		Sets the RMS level of the unmodulated RF carrier. The allowed range depends on several other settings, for example on the
		selected connector, the frequency and the external attenuation. For supported output level ranges, refer to the data
		sheet. \n
			:return: level: Unit: dBm
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:MBEacon:RFSettings:LEVel?')
		return Conversions.str_to_float(response)

	def set_level(self, level: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:RFSettings:LEVel \n
		Snippet: driver.source.avionics.generator.markerBeacon.rfSettings.set_level(level = 1.0) \n
		Sets the RMS level of the unmodulated RF carrier. The allowed range depends on several other settings, for example on the
		selected connector, the frequency and the external attenuation. For supported output level ranges, refer to the data
		sheet. \n
			:param level: Unit: dBm
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:MBEacon:RFSettings:LEVel {param}')

	def clone(self) -> 'RfSettings':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RfSettings(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfSettings:
	"""RfSettings commands group definition. 10 total commands, 2 Sub-groups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rfSettings", core, parent)

	@property
	def rf(self):
		"""rf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rf'):
			from .RfSettings_.Rf import Rf
			self._rf = Rf(self._core, self._base)
		return self._rf

	@property
	def farFrequency(self):
		"""farFrequency commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_farFrequency'):
			from .RfSettings_.FarFrequency import FarFrequency
			self._farFrequency = FarFrequency(self._core, self._base)
		return self._farFrequency

	# noinspection PyTypeChecker
	def get_connector(self) -> enums.InputConnector:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:CONNector \n
		Snippet: value: enums.InputConnector = driver.configure.afRf.measurement.rfSettings.get_connector() \n
		Selects the input connector for the measured RF signal. \n
			:return: input_connector: RFCom | RFIN
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:RFSettings:CONNector?')
		return Conversions.str_to_scalar_enum(response, enums.InputConnector)

	def set_connector(self, input_connector: enums.InputConnector) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:CONNector \n
		Snippet: driver.configure.afRf.measurement.rfSettings.set_connector(input_connector = enums.InputConnector.RFCom) \n
		Selects the input connector for the measured RF signal. \n
			:param input_connector: RFCom | RFIN
		"""
		param = Conversions.enum_scalar_to_str(input_connector, enums.InputConnector)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:RFSettings:CONNector {param}')

	def get_frequency(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:FREQuency \n
		Snippet: value: float = driver.configure.afRf.measurement.rfSettings.get_frequency() \n
		Sets the center frequency of the RF analyzer. \n
			:return: frequency: Range: 100 kHz to 3 GHz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:RFSettings:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, frequency: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:FREQuency \n
		Snippet: driver.configure.afRf.measurement.rfSettings.set_frequency(frequency = 1.0) \n
		Sets the center frequency of the RF analyzer. \n
			:param frequency: Range: 100 kHz to 3 GHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:RFSettings:FREQuency {param}')

	def get_envelope_power(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:ENPower \n
		Snippet: value: float = driver.configure.afRf.measurement.rfSettings.get_envelope_power() \n
		Sets the expected nominal power of the measured RF signal. The allowed range depends on several other settings, for
		example on the selected connector and the external attenuation. For supported ranges, refer to the data sheet. \n
			:return: exp_nominal_power: Unit: dBm
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:RFSettings:ENPower?')
		return Conversions.str_to_float(response)

	def set_envelope_power(self, exp_nominal_power: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:ENPower \n
		Snippet: driver.configure.afRf.measurement.rfSettings.set_envelope_power(exp_nominal_power = 1.0) \n
		Sets the expected nominal power of the measured RF signal. The allowed range depends on several other settings, for
		example on the selected connector and the external attenuation. For supported ranges, refer to the data sheet. \n
			:param exp_nominal_power: Unit: dBm
		"""
		param = Conversions.decimal_value_to_str(exp_nominal_power)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:RFSettings:ENPower {param}')

	def get_eattenuation(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:EATTenuation \n
		Snippet: value: float = driver.configure.afRf.measurement.rfSettings.get_eattenuation() \n
		Specifies the external attenuation in the input path. Negative values specify a gain. \n
			:return: rf_input_ext_att: Range: -50 dB to 90 dB, Unit: dB
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:RFSettings:EATTenuation?')
		return Conversions.str_to_float(response)

	def set_eattenuation(self, rf_input_ext_att: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:EATTenuation \n
		Snippet: driver.configure.afRf.measurement.rfSettings.set_eattenuation(rf_input_ext_att = 1.0) \n
		Specifies the external attenuation in the input path. Negative values specify a gain. \n
			:param rf_input_ext_att: Range: -50 dB to 90 dB, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(rf_input_ext_att)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:RFSettings:EATTenuation {param}')

	def get_rf_coupling(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:RFCoupling \n
		Snippet: value: bool = driver.configure.afRf.measurement.rfSettings.get_rf_coupling() \n
		Couples the frequency and channel settings of the analyzer to the corresponding generator settings. \n
			:return: rf_coupling: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:RFSettings:RFCoupling?')
		return Conversions.str_to_bool(response)

	def set_rf_coupling(self, rf_coupling: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:RFCoupling \n
		Snippet: driver.configure.afRf.measurement.rfSettings.set_rf_coupling(rf_coupling = False) \n
		Couples the frequency and channel settings of the analyzer to the corresponding generator settings. \n
			:param rf_coupling: OFF | ON
		"""
		param = Conversions.bool_to_str(rf_coupling)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:RFSettings:RFCoupling {param}')

	def get_dspace(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:DSPace \n
		Snippet: value: float = driver.configure.afRf.measurement.rfSettings.get_dspace() \n
		Configures the duplex spacing between the analyzer frequency and the generator frequency.
		Frequencyanalyzer = frequencygenerator + duplex spacing This command is only relevant with enabled RF coupling. \n
			:return: duplex_space: Range: -500 MHz to 500 MHz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:RFSettings:DSPace?')
		return Conversions.str_to_float(response)

	def set_dspace(self, duplex_space: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:DSPace \n
		Snippet: driver.configure.afRf.measurement.rfSettings.set_dspace(duplex_space = 1.0) \n
		Configures the duplex spacing between the analyzer frequency and the generator frequency.
		Frequencyanalyzer = frequencygenerator + duplex spacing This command is only relevant with enabled RF coupling. \n
			:param duplex_space: Range: -500 MHz to 500 MHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(duplex_space)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:RFSettings:DSPace {param}')

	def get_channel(self) -> int:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:CHANnel \n
		Snippet: value: int = driver.configure.afRf.measurement.rfSettings.get_channel() \n
		Specifies the center frequency of the RF analyzer via a channel number, according to the configured channel definition. \n
			:return: rf_channel: Range: 0 Ch to 9999 Ch, Unit: Ch
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:RFSettings:CHANnel?')
		return Conversions.str_to_int(response)

	def set_channel(self, rf_channel: int) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:CHANnel \n
		Snippet: driver.configure.afRf.measurement.rfSettings.set_channel(rf_channel = 1) \n
		Specifies the center frequency of the RF analyzer via a channel number, according to the configured channel definition. \n
			:param rf_channel: Range: 0 Ch to 9999 Ch, Unit: Ch
		"""
		param = Conversions.decimal_value_to_str(rf_channel)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:RFSettings:CHANnel {param}')

	def get_coffset(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:COFFset \n
		Snippet: value: float = driver.configure.afRf.measurement.rfSettings.get_coffset() \n
		Shifts the center frequency of the RF analyzer by a channel offset, relative to the frequency defined via the channel
		number. The range depends on the channel spacing, defined via method RsCma.Configure.AfRf.Measurement.Cdefinition.cspace. \n
			:return: channel_offset: Range: -Spacing/2 Hz to +Spacing/2 Hz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:RFSettings:COFFset?')
		return Conversions.str_to_float(response)

	def set_coffset(self, channel_offset: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:RFSettings:COFFset \n
		Snippet: driver.configure.afRf.measurement.rfSettings.set_coffset(channel_offset = 1.0) \n
		Shifts the center frequency of the RF analyzer by a channel offset, relative to the frequency defined via the channel
		number. The range depends on the channel spacing, defined via method RsCma.Configure.AfRf.Measurement.Cdefinition.cspace. \n
			:param channel_offset: Range: -Spacing/2 Hz to +Spacing/2 Hz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(channel_offset)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:RFSettings:COFFset {param}')

	def clone(self) -> 'RfSettings':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RfSettings(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class External:
	"""External commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("external", core, parent)

	# noinspection PyTypeChecker
	def get_li_range(self) -> enums.LockRangeExternal:
		"""SCPI: SYSTem:BASE:REFerence:EXTernal:LIRange \n
		Snippet: value: enums.LockRangeExternal = driver.system.base.reference.external.get_li_range() \n
		Selects the width of the lock-in range, used to synchronize to an external reference frequency source. \n
			:return: li_range: WIDE | MEDium | NARRow | INV INV means that the source is unusable, for example because of an ongoing adjustment
		"""
		response = self._core.io.query_str_with_opc('SYSTem:BASE:REFerence:EXTernal:LIRange?')
		return Conversions.str_to_scalar_enum(response, enums.LockRangeExternal)

	def set_li_range(self, li_range: enums.LockRangeExternal) -> None:
		"""SCPI: SYSTem:BASE:REFerence:EXTernal:LIRange \n
		Snippet: driver.system.base.reference.external.set_li_range(li_range = enums.LockRangeExternal.INV) \n
		Selects the width of the lock-in range, used to synchronize to an external reference frequency source. \n
			:param li_range: WIDE | MEDium | NARRow | INV INV means that the source is unusable, for example because of an ongoing adjustment
		"""
		param = Conversions.enum_scalar_to_str(li_range, enums.LockRangeExternal)
		self._core.io.write_with_opc(f'SYSTem:BASE:REFerence:EXTernal:LIRange {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ttime:
	"""Ttime commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ttime", core, parent)

	def get_first(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:TTIMe:FIRSt \n
		Snippet: value: float = driver.source.afRf.generator.dialing.scal.ttime.get_first() \n
		Defines the duration of a dual tone of a SELCAL sequence. \n
			:return: ttime: Range: 0.2 s to 3 s, Unit: s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:TTIMe:FIRSt?')
		return Conversions.str_to_float(response)

	def set_first(self, ttime: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:TTIMe:FIRSt \n
		Snippet: driver.source.afRf.generator.dialing.scal.ttime.set_first(ttime = 1.0) \n
		Defines the duration of a dual tone of a SELCAL sequence. \n
			:param ttime: Range: 0.2 s to 3 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(ttime)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:SCAL:TTIMe:FIRSt {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class First:
	"""First commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("first", core, parent)

	def get_level(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AOUT:FIRSt:LEVel \n
		Snippet: value: float = driver.configure.afRf.measurement.audioOutput.first.get_level() \n
		Specifies the output level for the AF1 OUT connector. Use this command, if you want to set different level units, e.g.
		dBm (Table 'Units relevant for remote commands') , or set the level for both connectors independently. \n
			:return: level: Range: 10E-6 V to 5 V, Unit: V
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:AOUT:FIRSt:LEVel?')
		return Conversions.str_to_float(response)

	def set_level(self, level: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AOUT:FIRSt:LEVel \n
		Snippet: driver.configure.afRf.measurement.audioOutput.first.set_level(level = 1.0) \n
		Specifies the output level for the AF1 OUT connector. Use this command, if you want to set different level units, e.g.
		dBm (Table 'Units relevant for remote commands') , or set the level for both connectors independently. \n
			:param level: Range: 10E-6 V to 5 V, Unit: V
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:AOUT:FIRSt:LEVel {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Code:
	"""Code commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("code", core, parent)

	def get_all(self) -> int:
		"""SCPI: SYSTem:ERRor:CODE:ALL \n
		Snippet: value: int = driver.system.error.code.get_all() \n
		Queries the error code numbers of all entries in the error queue and deletes all entries. \n
			:return: error_code: Comma-separated list of error codes 0 means that the queue is empty. Positive error codes are instrument-dependent. Negative error codes are reserved by the SCPI standard.
		"""
		response = self._core.io.query_str('SYSTem:ERRor:CODE:ALL?')
		return Conversions.str_to_int(response)

	def get_next(self) -> int:
		"""SCPI: SYSTem:ERRor:CODE[:NEXT] \n
		Snippet: value: int = driver.system.error.code.get_next() \n
		Queries the code number of the oldest entry in the error queue and deletes the entry. \n
			:return: error: 0 means that the queue is empty. Positive error codes are instrument-dependent. Negative error codes are reserved by the SCPI standard.
		"""
		response = self._core.io.query_str('SYSTem:ERRor:CODE:NEXT?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frange:
	"""Frange commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frange", core, parent)

	def get_stop(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FRANge:STOP \n
		Snippet: value: float = driver.configure.afRf.measurement.frequency.counter.frange.get_stop() \n
		Defines the maximum frequency for the search procedure. \n
			:return: upper: Range: 0 Hz to 3 GHz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FRANge:STOP?')
		return Conversions.str_to_float(response)

	def set_stop(self, upper: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FRANge:STOP \n
		Snippet: driver.configure.afRf.measurement.frequency.counter.frange.set_stop(upper = 1.0) \n
		Defines the maximum frequency for the search procedure. \n
			:param upper: Range: 0 Hz to 3 GHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(upper)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FRANge:STOP {param}')

	def get_start(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FRANge:STARt \n
		Snippet: value: float = driver.configure.afRf.measurement.frequency.counter.frange.get_start() \n
		Defines the minimum frequency for the search procedure. \n
			:return: lower: Range: 0 Hz to 3 GHz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FRANge:STARt?')
		return Conversions.str_to_float(response)

	def set_start(self, lower: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FRANge:STARt \n
		Snippet: driver.configure.afRf.measurement.frequency.counter.frange.set_start(lower = 1.0) \n
		Defines the minimum frequency for the search procedure. \n
			:param lower: Range: 0 Hz to 3 GHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(lower)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FRANge:STARt {param}')

	def get_enable(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FRANge:ENABle \n
		Snippet: value: bool = driver.configure.afRf.measurement.frequency.counter.frange.get_enable() \n
		Selects the frequency range to be searched. \n
			:return: to_limit: OFF | ON OFF Entire supported frequency range ON Frequency range defined by the commands method RsCma.Configure.AfRf.Measurement.Frequency.Counter.Frange.start and method RsCma.Configure.AfRf.Measurement.Frequency.Counter.Frange.stop
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FRANge:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, to_limit: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FRANge:ENABle \n
		Snippet: driver.configure.afRf.measurement.frequency.counter.frange.set_enable(to_limit = False) \n
		Selects the frequency range to be searched. \n
			:param to_limit: OFF | ON OFF Entire supported frequency range ON Frequency range defined by the commands method RsCma.Configure.AfRf.Measurement.Frequency.Counter.Frange.start and method RsCma.Configure.AfRf.Measurement.Frequency.Counter.Frange.stop
		"""
		param = Conversions.bool_to_str(to_limit)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FRANge:ENABle {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("enable", core, parent)

	def set(self, filter_enable: bool, notch=repcap.Notch.Default) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:NOTCh<Num>:ENABle \n
		Snippet: driver.configure.afRf.measurement.voip.filterPy.notch.enable.set(filter_enable = False, notch = repcap.Notch.Default) \n
		No command help available \n
			:param filter_enable: No help available
			:param notch: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Notch')"""
		param = Conversions.bool_to_str(filter_enable)
		notch_cmd_val = self._base.get_repcap_cmd_value(notch, repcap.Notch)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:NOTCh{notch_cmd_val}:ENABle {param}')

	def get(self, notch=repcap.Notch.Default) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:NOTCh<Num>:ENABle \n
		Snippet: value: bool = driver.configure.afRf.measurement.voip.filterPy.notch.enable.get(notch = repcap.Notch.Default) \n
		No command help available \n
			:param notch: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Notch')
			:return: filter_enable: No help available"""
		notch_cmd_val = self._base.get_repcap_cmd_value(notch, repcap.Notch)
		response = self._core.io.query_str(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:NOTCh{notch_cmd_val}:ENABle?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Af:
	"""Af commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("af", core, parent)

	def get_scount(self) -> int:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:AF:SCOunt \n
		Snippet: value: int = driver.configure.afRf.measurement.multiEval.af.get_scount() \n
		Specifies the number of measurement intervals per measurement cycle for AF results. One measurement interval delivers a
		single 'Current' value per result. \n
			:return: statistic_count: Range: 1 to 1000
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:AF:SCOunt?')
		return Conversions.str_to_int(response)

	def set_scount(self, statistic_count: int) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:AF:SCOunt \n
		Snippet: driver.configure.afRf.measurement.multiEval.af.set_scount(statistic_count = 1) \n
		Specifies the number of measurement intervals per measurement cycle for AF results. One measurement interval delivers a
		single 'Current' value per result. \n
			:param statistic_count: Range: 1 to 1000
		"""
		param = Conversions.decimal_value_to_str(statistic_count)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:AF:SCOunt {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Crest:
	"""Crest commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("crest", core, parent)

	def set(self, crest_factor: enums.CrestFactor, internalGen=repcap.InternalGen.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:MTONe:CRESt \n
		Snippet: driver.source.afRf.generator.internalGenerator.multiTone.crest.set(crest_factor = enums.CrestFactor.LOW, internalGen = repcap.InternalGen.Default) \n
		Configures the crest factor for multitone signal generation. \n
			:param crest_factor: MAXimum | LOW
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')"""
		param = Conversions.enum_scalar_to_str(crest_factor, enums.CrestFactor)
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:MTONe:CRESt {param}')

	# noinspection PyTypeChecker
	def get(self, internalGen=repcap.InternalGen.Default) -> enums.CrestFactor:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:MTONe:CRESt \n
		Snippet: value: enums.CrestFactor = driver.source.afRf.generator.internalGenerator.multiTone.crest.get(internalGen = repcap.InternalGen.Default) \n
		Configures the crest factor for multitone signal generation. \n
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')
			:return: crest_factor: MAXimum | LOW"""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		response = self._core.io.query_str(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:MTONe:CRESt?')
		return Conversions.str_to_scalar_enum(response, enums.CrestFactor)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Display:
	"""Display commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("display", core, parent)

	def get_state(self) -> bool:
		"""SCPI: CONFigure:BASE:DISPlay:STATe \n
		Snippet: value: bool = driver.configure.base.display.get_state() \n
		Switches the instrument display off or on. \n
			:return: display_state: OFF | ON OFF: display off (black screen) ON: display on
		"""
		response = self._core.io.query_str('CONFigure:BASE:DISPlay:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, display_state: bool) -> None:
		"""SCPI: CONFigure:BASE:DISPlay:STATe \n
		Snippet: driver.configure.base.display.set_state(display_state = False) \n
		Switches the instrument display off or on. \n
			:param display_state: OFF | ON OFF: display off (black screen) ON: display on
		"""
		param = Conversions.bool_to_str(display_state)
		self._core.io.write(f'CONFigure:BASE:DISPlay:STATe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RifBandwidth:
	"""RifBandwidth commands group definition. 16 total commands, 6 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rifBandwidth", core, parent)

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_frequency'):
			from .RifBandwidth_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def slevel(self):
		"""slevel commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_slevel'):
			from .RifBandwidth_.Slevel import Slevel
			self._slevel = Slevel(self._core, self._base)
		return self._slevel

	@property
	def nlevel(self):
		"""nlevel commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_nlevel'):
			from .RifBandwidth_.Nlevel import Nlevel
			self._nlevel = Nlevel(self._core, self._base)
		return self._nlevel

	@property
	def bandwidth(self):
		"""bandwidth commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_bandwidth'):
			from .RifBandwidth_.Bandwidth import Bandwidth
			self._bandwidth = Bandwidth(self._core, self._base)
		return self._bandwidth

	@property
	def coffset(self):
		"""coffset commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_coffset'):
			from .RifBandwidth_.Coffset import Coffset
			self._coffset = Coffset(self._core, self._base)
		return self._coffset

	@property
	def signalQuality(self):
		"""signalQuality commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_signalQuality'):
			from .RifBandwidth_.SignalQuality import SignalQuality
			self._signalQuality = SignalQuality(self._core, self._base)
		return self._signalQuality

	def clone(self) -> 'RifBandwidth':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RifBandwidth(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FftSpecAn:
	"""FftSpecAn commands group definition. 13 total commands, 2 Sub-groups, 9 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fftSpecAn", core, parent)

	@property
	def peakSearch(self):
		"""peakSearch commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_peakSearch'):
			from .FftSpecAn_.PeakSearch import PeakSearch
			self._peakSearch = PeakSearch(self._core, self._base)
		return self._peakSearch

	@property
	def marker(self):
		"""marker commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_marker'):
			from .FftSpecAn_.Marker import Marker
			self._marker = Marker(self._core, self._base)
		return self._marker

	def get_timeout(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:TOUT \n
		Snippet: value: float = driver.configure.gprfMeasurement.fftSpecAn.get_timeout() \n
		Defines a timeout for the measurement. The timer is started when the measurement is initiated via a READ or INIT command.
		It is not started if the measurement is initiated via the graphical user interface. The timer is reset after the first
		measurement cycle. If the first measurement cycle has not been completed when the timer expires, the measurement is
		stopped and the reliability indicator is set to 1. Still running READ, FETCh or CALCulate commands are completed,
		returning the available results. At least for some results, there are no values at all or the statistical depth has not
		been reached. A timeout of 0 s corresponds to an infinite measurement timeout. \n
			:return: tcd_timeout: Unit: s
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:TOUT?')
		return Conversions.str_to_float(response)

	def set_timeout(self, tcd_timeout: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:TOUT \n
		Snippet: driver.configure.gprfMeasurement.fftSpecAn.set_timeout(tcd_timeout = 1.0) \n
		Defines a timeout for the measurement. The timer is started when the measurement is initiated via a READ or INIT command.
		It is not started if the measurement is initiated via the graphical user interface. The timer is reset after the first
		measurement cycle. If the first measurement cycle has not been completed when the timer expires, the measurement is
		stopped and the reliability indicator is set to 1. Still running READ, FETCh or CALCulate commands are completed,
		returning the available results. At least for some results, there are no values at all or the statistical depth has not
		been reached. A timeout of 0 s corresponds to an infinite measurement timeout. \n
			:param tcd_timeout: Unit: s
		"""
		param = Conversions.decimal_value_to_str(tcd_timeout)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:TOUT {param}')

	# noinspection PyTypeChecker
	def get_amode(self) -> enums.AveragingMode:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:AMODe \n
		Snippet: value: enums.AveragingMode = driver.configure.gprfMeasurement.fftSpecAn.get_amode() \n
		Defines how the average FFT trace is derived from the current trace. \n
			:return: averaging_mode: LINear | LOGarithmic LINear Averaging of the linear powers LOGarithmic Averaging of the dBm values
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:AMODe?')
		return Conversions.str_to_scalar_enum(response, enums.AveragingMode)

	def set_amode(self, averaging_mode: enums.AveragingMode) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:AMODe \n
		Snippet: driver.configure.gprfMeasurement.fftSpecAn.set_amode(averaging_mode = enums.AveragingMode.LINear) \n
		Defines how the average FFT trace is derived from the current trace. \n
			:param averaging_mode: LINear | LOGarithmic LINear Averaging of the linear powers LOGarithmic Averaging of the dBm values
		"""
		param = Conversions.enum_scalar_to_str(averaging_mode, enums.AveragingMode)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:AMODe {param}')

	# noinspection PyTypeChecker
	def get_detector(self) -> enums.DetectorSimple:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:DETector \n
		Snippet: value: enums.DetectorSimple = driver.configure.gprfMeasurement.fftSpecAn.get_detector() \n
		Defines how a spectrum diagram point is calculated from adjacent frequency domain samples. \n
			:return: detector: PEAK | RMS PEAK The sample with the largest power is displayed. RMS The RMS value of the samples is displayed.
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:DETector?')
		return Conversions.str_to_scalar_enum(response, enums.DetectorSimple)

	def set_detector(self, detector: enums.DetectorSimple) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:DETector \n
		Snippet: driver.configure.gprfMeasurement.fftSpecAn.set_detector(detector = enums.DetectorSimple.PEAK) \n
		Defines how a spectrum diagram point is calculated from adjacent frequency domain samples. \n
			:param detector: PEAK | RMS PEAK The sample with the largest power is displayed. RMS The RMS value of the samples is displayed.
		"""
		param = Conversions.enum_scalar_to_str(detector, enums.DetectorSimple)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:DETector {param}')

	def get_fft_length(self) -> int:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:FFTLength \n
		Snippet: value: int = driver.configure.gprfMeasurement.fftSpecAn.get_fft_length() \n
		Specifies the number of samples used for the FFT analysis. \n
			:return: length: You can enter values between 1024 and 16384. The setting is rounded to the closest integer power of two.
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:FFTLength?')
		return Conversions.str_to_int(response)

	def set_fft_length(self, length: int) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:FFTLength \n
		Snippet: driver.configure.gprfMeasurement.fftSpecAn.set_fft_length(length = 1) \n
		Specifies the number of samples used for the FFT analysis. \n
			:param length: You can enter values between 1024 and 16384. The setting is rounded to the closest integer power of two.
		"""
		param = Conversions.decimal_value_to_str(length)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:FFTLength {param}')

	def get_fspan(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:FSPan \n
		Snippet: value: float = driver.configure.gprfMeasurement.fftSpecAn.get_fspan() \n
		Defines the frequency range to be measured and thus the x-axis of the spectrum result diagram. \n
			:return: frequency_span: You can enter values between 10 kHz and 20 MHz. The setting is rounded to the closest of the following values: 10 / 20 / 40 / 80 / 160 / 320 / 640 kHz 1.25 / 2.5 / 5 / 10 / 20 MHz Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:FSPan?')
		return Conversions.str_to_float(response)

	def set_fspan(self, frequency_span: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:FSPan \n
		Snippet: driver.configure.gprfMeasurement.fftSpecAn.set_fspan(frequency_span = 1.0) \n
		Defines the frequency range to be measured and thus the x-axis of the spectrum result diagram. \n
			:param frequency_span: You can enter values between 10 kHz and 20 MHz. The setting is rounded to the closest of the following values: 10 / 20 / 40 / 80 / 160 / 320 / 640 kHz 1.25 / 2.5 / 5 / 10 / 20 MHz Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(frequency_span)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:FSPan {param}')

	def get_mo_exception(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:MOEXception \n
		Snippet: value: bool = driver.configure.gprfMeasurement.fftSpecAn.get_mo_exception() \n
		Specifies whether measurement results that the R&S CMA180 identifies as faulty or inaccurate are rejected. \n
			:return: meas_on_exception: OFF | ON OFF Faulty results are rejected ON Results are never rejected
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:MOEXception?')
		return Conversions.str_to_bool(response)

	def set_mo_exception(self, meas_on_exception: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:MOEXception \n
		Snippet: driver.configure.gprfMeasurement.fftSpecAn.set_mo_exception(meas_on_exception = False) \n
		Specifies whether measurement results that the R&S CMA180 identifies as faulty or inaccurate are rejected. \n
			:param meas_on_exception: OFF | ON OFF Faulty results are rejected ON Results are never rejected
		"""
		param = Conversions.bool_to_str(meas_on_exception)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:MOEXception {param}')

	# noinspection PyTypeChecker
	def get_repetition(self) -> enums.Repeat:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:REPetition \n
		Snippet: value: enums.Repeat = driver.configure.gprfMeasurement.fftSpecAn.get_repetition() \n
		Selects whether the measurement is repeated continuously or not. \n
			:return: repetition: SINGleshot | CONTinuous SINGleshot Single-shot measurement, stopped after one measurement cycle CONTinuous Continuous measurement, running until explicitly terminated
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:REPetition?')
		return Conversions.str_to_scalar_enum(response, enums.Repeat)

	def set_repetition(self, repetition: enums.Repeat) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:REPetition \n
		Snippet: driver.configure.gprfMeasurement.fftSpecAn.set_repetition(repetition = enums.Repeat.CONTinuous) \n
		Selects whether the measurement is repeated continuously or not. \n
			:param repetition: SINGleshot | CONTinuous SINGleshot Single-shot measurement, stopped after one measurement cycle CONTinuous Continuous measurement, running until explicitly terminated
		"""
		param = Conversions.enum_scalar_to_str(repetition, enums.Repeat)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:REPetition {param}')

	def get_rcoupling(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:RCOupling \n
		Snippet: value: bool = driver.configure.gprfMeasurement.fftSpecAn.get_rcoupling() \n
		Couples the repetition mode (single shot or continuous) of all measurements. \n
			:return: repetition_coupl: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:RCOupling?')
		return Conversions.str_to_bool(response)

	def set_rcoupling(self, repetition_coupl: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:RCOupling \n
		Snippet: driver.configure.gprfMeasurement.fftSpecAn.set_rcoupling(repetition_coupl = False) \n
		Couples the repetition mode (single shot or continuous) of all measurements. \n
			:param repetition_coupl: OFF | ON
		"""
		param = Conversions.bool_to_str(repetition_coupl)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:RCOupling {param}')

	def get_scount(self) -> int:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:SCOunt \n
		Snippet: value: int = driver.configure.gprfMeasurement.fftSpecAn.get_scount() \n
		Specifies the number of measurement intervals per measurement cycle. One measurement interval comprises the number of
		samples defined by the 'FFT Length'. \n
			:return: statistic_count: Range: 1 to 1000
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:SCOunt?')
		return Conversions.str_to_int(response)

	def set_scount(self, statistic_count: int) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:SCOunt \n
		Snippet: driver.configure.gprfMeasurement.fftSpecAn.set_scount(statistic_count = 1) \n
		Specifies the number of measurement intervals per measurement cycle. One measurement interval comprises the number of
		samples defined by the 'FFT Length'. \n
			:param statistic_count: Range: 1 to 1000
		"""
		param = Conversions.decimal_value_to_str(statistic_count)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:FFTSanalyzer:SCOunt {param}')

	def clone(self) -> 'FftSpecAn':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FftSpecAn(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Current:
	"""Current commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("current", core, parent)

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Frequency: float: Frequency of the measured AF signal Unit: Hz
			- Level: float: Effective level of the AC component of the measured AF signal Unit: V
			- Dc_Level: float: Level of the DC component of the measured AF signal (input coupling DC required) Unit: V"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Frequency'),
			ArgStruct.scalar_float('Level'),
			ArgStruct.scalar_float('Dc_Level')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Frequency: float = None
			self.Level: float = None
			self.Dc_Level: float = None

	def fetch(self, audioInput=repcap.AudioInput.Default) -> ResultData:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:AIN<Nr>:AFSignal:CURRent \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.audioInput.afSignal.current.fetch(audioInput = repcap.AudioInput.Default) \n
		Queries the AF frequency and level results measured for an AF input path. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: structure: for return value, see the help for ResultData structure arguments."""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:AIN{audioInput_cmd_val}:AFSignal:CURRent?', self.__class__.ResultData())

	def read(self, audioInput=repcap.AudioInput.Default) -> ResultData:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:AIN<Nr>:AFSignal:CURRent \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.audioInput.afSignal.current.read(audioInput = repcap.AudioInput.Default) \n
		Queries the AF frequency and level results measured for an AF input path. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: structure: for return value, see the help for ResultData structure arguments."""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		return self._core.io.query_struct(f'READ:AFRF:MEASurement<Instance>:MEValuation:AIN{audioInput_cmd_val}:AFSignal:CURRent?', self.__class__.ResultData())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rssi:
	"""Rssi commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rssi", core, parent)

	def get_code(self) -> int:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:RSSI:CODE \n
		Snippet: value: int = driver.configure.afRf.measurement.voip.rssi.get_code() \n
		No command help available \n
			:return: code: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:RSSI:CODE?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Range:
	"""Range commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("range", core, parent)

	# noinspection PyTypeChecker
	class RangeStruct(StructBase):
		"""Structure for setting input parameters. Fields: \n
			- Xrange_Lower: float: Unit: Hz
			- Xrange_Upper: float: Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_float('Xrange_Lower'),
			ArgStruct.scalar_float('Xrange_Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Xrange_Lower: float = None
			self.Xrange_Upper: float = None

	def set(self, structure: RangeStruct, marker=repcap.Marker.Nr1) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:MARKer<nr>:RANGe \n
		Snippet: driver.configure.gprfMeasurement.spectrum.frequency.marker.range.set(value = [PROPERTY_STRUCT_NAME](), marker = repcap.Marker.Nr1) \n
		Specifies a peak search range, for marker number <no> and frequency sweep mode. Marker number one is the reference marker.
		The allowed range of frequency values corresponds to the measured span. \n
			:param structure: for set value, see the help for RangeStruct structure arguments.
			:param marker: optional repeated capability selector. Default value: Nr1"""
		marker_cmd_val = self._base.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write_struct(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:MARKer{marker_cmd_val}:RANGe', structure)

	def get(self, marker=repcap.Marker.Nr1) -> RangeStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:MARKer<nr>:RANGe \n
		Snippet: value: RangeStruct = driver.configure.gprfMeasurement.spectrum.frequency.marker.range.get(marker = repcap.Marker.Nr1) \n
		Specifies a peak search range, for marker number <no> and frequency sweep mode. Marker number one is the reference marker.
		The allowed range of frequency values corresponds to the measured span. \n
			:param marker: optional repeated capability selector. Default value: Nr1
			:return: structure: for return value, see the help for RangeStruct structure arguments."""
		marker_cmd_val = self._base.get_repcap_cmd_value(marker, repcap.Marker)
		return self._core.io.query_struct(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FREQuency:MARKer{marker_cmd_val}:RANGe?', self.__class__.RangeStruct())
